plot: Casual Impact Plots

Description Usage Arguments Author(s)

Description

Provides visual diagnostis for causal effects.

Usage

1
2
3
4
5
## S3 method for class 'tscausal'
plot(x, y = NULL, median_color = "black", 
median_type = 1, median_width = 2, gradient_color = "orange", 
interval_color = "red", interval_type = 2, interval_width = 2, 
ylim = NULL, ylab = "", n_original = NULL, ...)

Arguments

x

An object of class “tscausal” generated from calling tscausal.

y

Not used.

median_color

The color used for plotting the median value.

median_type

The line type for the median.

median_width

The width of the median line.

gradient_color

The gradient color to use for the distribution.

interval_color

The color of the quantile lines

interval_type

The line type for the quantiles.

interval_width

The width of the quantile lines.

ylim

User specified limits for y.

ylab

User specified label for y.

n_original

Number of points from the end of the intervention period to include in the plotting. For large time series it makes sense to not plot the entire period pre-intervention as this will visually obscure the post-intervention effects.

...

Additional parameters passed to the “plot.tsmodel.distribution” functions in the “tsmethods” package.

Author(s)

Alexios Galanos


tsmodels/tscausal documentation built on Dec. 31, 2020, 9:38 a.m.