tsreport: Report Causal Impact Analysis

Description Usage Arguments Value Author(s) References

Description

Provides a verbose analysis of the causal impact.

Usage

1
2
3
4
## S3 method for class 'tscausal'
tsreport(object, digits = 4, doc_template = NULL, 
type = c("screen","pdf","doc","html"), output_dir = "/", 
args = list(name = "Causal Analysis", frequency = NULL, model = NULL), ...)

Arguments

object

An object of class “tscausal” generated from calling tscausal.

digits

Number of digits to print.

doc_template

Filename (full path) of a docx which can be used as a template for the word document option.

type

The type of output.

output_dir

A directory where the output is written and the causal object saved.

args

An additional list of arguments used in the generation of the report.

...

Not currently used.

Value

Text output

Author(s)

Alexios Galanos with supporting code borrowed from the CausalImpact package of Scott.

References

Brodersen, Kay H and Gallusser, Fabian and Koehler, Jim and Remy, Nicolas and Scott, Steven L and others (2016). Inferring causal impact using Bayesian structural time-series models. The Annals of Applied Statistics, 9 (1), 247-274.


tsmodels/tscausal documentation built on Dec. 31, 2020, 9:38 a.m.