Description Usage Arguments Author(s)
Provides visual diagnostis for causal effects.
1 2 3 4 5 |
x |
An object of class “tscausal” generated from
calling |
y |
Not used. |
median_color |
The color used for plotting the median value. |
median_type |
The line type for the median. |
median_width |
The width of the median line. |
gradient_color |
The gradient color to use for the distribution. |
interval_color |
The color of the quantile lines |
interval_type |
The line type for the quantiles. |
interval_width |
The width of the quantile lines. |
ylim |
User specified limits for y. |
ylab |
User specified label for y. |
n_original |
Number of points from the end of the intervention period to include in the plotting. For large time series it makes sense to not plot the entire period pre-intervention as this will visually obscure the post-intervention effects. |
... |
Additional parameters passed to the “plot.tsmodel.distribution” functions in the “tsmethods” package. |
Alexios Galanos
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.