Description Usage Arguments Value Author(s) References
Provides a verbose analysis of the causal impact.
1 2 3 4 |
object |
An object of class “tscausal” generated from
calling |
digits |
Number of digits to print. |
doc_template |
Filename (full path) of a docx which can be used as a template for the word document option. |
type |
The type of output. |
output_dir |
A directory where the output is written and the causal object saved. |
args |
An additional list of arguments used in the generation of the report. |
... |
Not currently used. |
Text output
Alexios Galanos with supporting code borrowed from the CausalImpact package of Scott.
Brodersen, Kay H and Gallusser, Fabian and Koehler, Jim and Remy, Nicolas and Scott, Steven L and others (2016). Inferring causal impact using Bayesian structural time-series models. The Annals of Applied Statistics, 9 (1), 247-274.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.